==> imwiki-0.6.0a.tar.gz: imwiki-0.6.0a/imLib/Category.py <==
# -*- coding: utf8 -*-
import os

import Repository
import utils
import Page
import Permission

sep = '/' # FIXME 음. /가 좋은가? :나 ::가 좋지않을까. config에서 설정할 수 있는게 좋을까?

from WikiException import WikiException
class NotExistCategory(WikiException): pass
class AttributeError(WikiException): pass

def categoryPathToFilePath(categoryPath):
	nameList = categoryPath.split(sep)
	encNameList = [utils.encode(name) for name in nameList]
	return '/'.join(encNameList)

def getCategoryByCategoryPath(categoryPath):
	nameList = filter(None, categoryPath.split(sep))
	category = Category()
	if not nameList:
		return category
	for name in nameList:
		category = category.getCategory(name) # 존재하지 않는 name일땐 None을 리텀
		if not category: 
			break
	return category

def createCategoryByCategoryPath(categoryPath): 
	nameList = categoryPath.split(sep)
	category = Category()
	for name in nameList:
		prev = category
		category = category.getCategory(name)
		if not category: 
			category = prev.createCategory(name)  
	return category

class Category:
	def __init__(self, parent=None, categoryName=None): 
		if parent and categoryName:
			self.parent = parent
			self.categoryName = categoryName
			self.categoryPath = parent.joinCategoryPath(categoryName)
			self._setFilePath() # self.dirPath
		elif not (parent or categoryName): # root
			self.parent = None
			self.categoryName = ''
			self.categoryPath = ''
			self.dirPath = Repository.getPageRepository()
		else:
			raise NotExistCategory # FIXME 적당하지 않은 값으로 생성하려 했다.
		if not os.path.isdir(self.dirPath):
			raise NotExistCategory # FIXME 카테고리가 없다.
		self.loadPerm()

	def _setFilePath(self):
		self.dirPath = os.path.join(Repository.getPageRepository(), categoryPathToFilePath(self.categoryPath))

	def loadPerm(self):
		permPath = os.path.join(self.dirPath, '__Attr__')
		if not os.path.isfile(permPath):
			raise AttributeError
		s = file(permPath, 'rb').read()
		self.perms = Permission.Permission(s)

	def joinCategoryPath(self, categoryName):
		if self.categoryPath == '':
			return categoryName
		else:
			return self.categoryPath + sep + categoryName

	def getCategory(self, categoryName):
		if not categoryName.replace('/', ''):
			raise NotExistCategory# FIXME 카테고리 이름이 없음
		if not os.path.isdir(os.path.join(self.dirPath, utils.encode(categoryName))):
			return None
		return Category(self, categoryName)

	def createCategory(self, categoryName, perms=None): # FIXME 카테고리가 존재할 때. 폴더가 아니라 파일로 존재하면? 여기서 처리해줄 필요가 있지않나?
		childPath = os.path.join(self.dirPath, utils.encode(categoryName))
		os.mkdir(childPath)
		if not perms:
			perms = self.perms
		file(os.path.join(childPath, '__Attr__'), 'wb').write('%s' % perms) # perms는 Permission 객체와 문자열 모두 사용 가능 
		return Category(self, categoryName)

	def XXXgetDescendants(self):
		L = []
		for category in self.getCategoryList():
			L.append(category)
			L.extend(category.getDescendants())
		return L


	def XXXgetNameOfDescendants(self):
		D = {}
		for category in self.getCategoryList():
			D[category.categoryName] = category.getNameOfDescendants()
		return D

	def getPage(self, pageName):
		if not os.path.isfile(os.path.join(self.dirPath, utils.encode(pageName))):
			return None
		return Page.Page(self, pageName)

	def getPageList(self, myFilter=None):
		fileNameList = os.walk(self.dirPath).next()[2]
		fileNameList.remove('__Attr__')
		pageNameList = [utils.decode(fileName) for fileName in fileNameList]
		pageList = [Page.Page(self, pageName) for pageName in pageNameList]
		if myFilter:
			return filter(myFilter, pageList)
		return pageList 

	def getPageListFromDescendants(self, myFilter=None):
		L = self.getPageList(myFilter)
		for category in self.getCategoryList():
			L.extend(category.getPageListFromDescendants(myFilter))
		return L

	def getCategoryList(self):
		dirNameList = os.walk(self.dirPath).next()[1]
		categoryNameList = [utils.decode(dirName) for dirName in dirNameList]
		categoryList = [Category(self, categoryName) for categoryName in categoryNameList]
		return categoryList

==> imwiki-0.6.1.tar.gz: imwiki-0.6.1/imLib/Category.py <==
# -*- coding: utf8 -*-
import os

import Repository
import utils
import Page
import Permission

sep = '/' # FIXME 음. /가 좋은가? :나 ::가 좋지않을까. config에서 설정할 수 있는게 좋을까? : 등으로 고칠 시 다른곳에서 quote하는 부분이 있을테니 고쳐줘야함.(특히 encode함수 사용하는 부분들)

from WikiException import WikiException
class ExistPage(WikiException): pass
class ExistCategory(WikiException): pass
class NotExistCategory(WikiException): pass
class AttributeError(WikiException): pass

def categoryPathToFilePath(categoryPath):
	nameList = categoryPath.split(sep)
	encNameList = [utils.encode(name) for name in nameList]
	return '/'.join(encNameList)

def getCategoryByCategoryPath(categoryPath, exist=None):
	nameList = filter(None, categoryPath.split(sep))
	category = Category()
	if not nameList:
		return category
	for name in nameList:
		prev = category
		category = category.getCategory(name) # 존재하지 않는 name일땐 None을 리텀
		if not category: 
			break
	if exist:
		return prev
	return category

def createCategoryByCategoryPath(categoryPath, perms=None): 
	nameList = categoryPath.split(sep)
	category = Category()
	for name in nameList:
		prev = category
		category = category.getCategory(name)
		if not category: 
			category = prev.createCategory(name, perms)  
	return category

class Category:
	def __init__(self, parent=None, categoryName=None): 
		if parent and categoryName:
			self.parent = parent
			self.categoryName = categoryName
			self.categoryPath = parent.joinCategoryPath(categoryName)
			self._setFilePath() # self.dirPath
		elif not (parent or categoryName): # root
			self.parent = None
			self.categoryName = ''
			self.categoryPath = ''
			self.dirPath = Repository.getPageRepository()
		else:
			raise NotExistCategory # FIXME 적당하지 않은 값으로 생성하려 했다.
		if not os.path.isdir(self.dirPath):
			raise NotExistCategory # FIXME 카테고리가 없다.
		self.loadPerms()

	def _setFilePath(self):
		self.dirPath = os.path.join(Repository.getPageRepository(), categoryPathToFilePath(self.categoryPath))

	def loadPerms(self):
		permPath = os.path.join(self.dirPath, '__Attr__')
		if not os.path.isfile(permPath):
			raise AttributeError
		s = file(permPath, 'rb').read()
		self.perms = Permission.Permission(s)
	def editPerms(self, perms):
		file(os.path.join(self.dirPath, '__Attr__'), 'wb').write('%s' % perms)
		self.loadPerms()
	def joinCategoryPath(self, categoryName):
		if self.categoryPath == '':
			return categoryName
		else:
			return self.categoryPath + sep + categoryName

	def getCategory(self, categoryName):
		if not categoryName.replace('/', ''):
			raise NotExistCategory# FIXME 카테고리 이름이 없음
		if not os.path.isdir(os.path.join(self.dirPath, utils.encode(categoryName))):
			return None
		return Category(self, categoryName)

	def createCategory(self, categoryName, perms=None): # FIXME 카테고리가 존재할 때. 폴더가 아니라 파일로 존재하면? 여기서 처리해줄 필요가 있지않나?
		childPath = os.path.join(self.dirPath, utils.encode(categoryName))
		if os.path.isdir(childPath):
			raise ExistCategory
		if os.path.isfile(childPath):
			raise ExistPage
		os.mkdir(childPath)
		if not perms:
			perms = self.perms
		file(os.path.join(childPath, '__Attr__'), 'wb').write('%s' % perms) # perms는 Permission 객체와 문자열 모두 사용 가능 
		return Category(self, categoryName)

	def XXXgetDescendants(self):
		L = []
		for category in self.getCategoryList():
			L.append(category)
			L.extend(category.getDescendants())
		return L


	def XXXgetNameOfDescendants(self):
		D = {}
		for category in self.getCategoryList():
			D[category.categoryName] = category.getNameOfDescendants()
		return D

	def getPage(self, pageName):
		if not os.path.isfile(os.path.join(self.dirPath, utils.encode(pageName))):
			return None
		return Page.Page(self, pageName)

	def getPageList(self, myFilter=None):
		fileNameList = os.walk(self.dirPath).next()[2]
		fileNameList.remove('__Attr__')
		pageNameList = [utils.decode(fileName) for fileName in fileNameList]
		pageList = [Page.Page(self, pageName) for pageName in pageNameList]
		if myFilter:
			return filter(myFilter, pageList)
		return pageList 

	def getPageListFromDescendants(self, myFilter=None):
		L = self.getPageList(myFilter)
		for category in self.getCategoryList():
			L.extend(category.getPageListFromDescendants(myFilter))
		return L

	def getCategoryList(self):
		dirNameList = os.walk(self.dirPath).next()[1]
		categoryNameList = [utils.decode(dirName) for dirName in dirNameList]
		categoryList = [Category(self, categoryName) for categoryName in categoryNameList]
		return categoryList
